summaryrefslogtreecommitdiffstats
path: root/kcron/ktlistcron.h
diff options
context:
space:
mode:
Diffstat (limited to 'kcron/ktlistcron.h')
-rw-r--r--kcron/ktlistcron.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/kcron/ktlistcron.h b/kcron/ktlistcron.h
index 9fe5fe2..713a375 100644
--- a/kcron/ktlistcron.h
+++ b/kcron/ktlistcron.h
@@ -19,7 +19,7 @@
#include "ktlistitem.h"
/**
* QListViewItem view of a CTCron.
*/
class KTListCron : public KTListItem
{
@@ -33,12 +33,12 @@ public:
/**
* Construct tasks or variables folder from root.
*/
- KTListCron(QListView* parent, const char* name, CTCron* _ctcron);
+ KTListCron(TQListView* parent, const char* name, CTCron* _ctcron);
/**
* Construct user folder from root.
*/
- KTListCron(QListView* parent, CTCron* _ctcron);
+ KTListCron(TQListView* parent, CTCron* _ctcron);
/**
* Refresh.
@@ -19,7 +19,7 @@
#include "ktlistitem.h"
/**
- * QListViewItem view of a CTCron.
+ * TQListViewItem view of a CTCron.
*/
class KTListCron : public KTListItem